# sum-dict

Tools for working with dictionaries containing numeric values

## Install

```bash
pip install sum-dict
```

## Using

```python
import sum_dict
```

## Author

[Geza Kovacs](https://github.com/gkovacs)

## License

MIT
